@@ -29,7 +29,7 @@
  *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *  Last-modified: Wed 16 Jul 2008 14:38:00 JST
+ *  Last-modified: Sat 25 Oct 2008 04:28:00 JST
  */
 /* ------------------------------------------------------------------------- */
 #ifndef CLX_SOCKET_H
@@ -75,7 +75,7 @@ namespace clx {
 			this->assign(s);
 		}
 		
-		virtual ~basic_rawsocket() { this->decrement(); }
+		virtual ~basic_rawsocket() throw() { this->decrement(); }
 		
 		basic_rawsocket& operator=(const basic_rawsocket& cp) {
 			return this->assign(cp);
@@ -96,17 +96,16 @@ namespace clx {
 		basic_rawsocket& assign(socket_int s) {
 			this->decrement();
 			if (s >= 0) p_ = new shared_counter(s);
-			check_alloc(p_ != NULL);
+			if (p_ == NULL) throw std::bad_alloc();
 			return *this;
 		}
 		
 		virtual socket_int open() {
 			this->decrement();
 			socket_int s = open_socket(Family, Type, Protocol);
-			check_alloc(s >= 0);
 			
 			p_ = new shared_counter(s);
-			check_alloc(p_ != NULL);
+			if (p_ == NULL) throw std::bad_alloc();
 			return p_->socket();
 		}
 		
@@ -142,7 +141,7 @@ namespace clx {
 		
 		void decrement() {
 			if (p_ != NULL && p_->decrement() == 0) {
-				this->close();
+				if (p_->socket() >= 0) close_socket(p_->socket());
 				delete p_;
 				p_ = NULL;
 			}
